searchData={"items":[{"type":"module","title":"SmartIndentationEngine","doc":"A custom EEx engine that helps maintain proper indentation.\n\nThis engine extends the EEx.SmartEngine functionality and adds support for the\npipe marker (`<%|`) which can be used like this:\n\n    <%| if cond do %>\n      Some text\n    <% end %>\n\nThis marker will reindent the output of the block so that it's aligned with\nindentation of the `if` line.","ref":"SmartIndentationEngine.html"},{"type":"module","title":"SmartIndentationEngine.Template","doc":"Provides the `~TT` sigil to compile templates with the\n`SmartIndentationEngine`, and the `include/2` macro for rendering partials.","ref":"SmartIndentationEngine.Template.html"},{"type":"macro","title":"SmartIndentationEngine.Template.include/2","doc":"Renders a partial defined by the given function name.","ref":"SmartIndentationEngine.Template.html#include/2"},{"type":"macro","title":"Example - SmartIndentationEngine.Template.include/2","doc":"<%= include :partial %>\n    <%= include :partial, name: true %>\n\nThis will call `partial/1` function with the current assigns.","ref":"SmartIndentationEngine.Template.html#include/2-example"},{"type":"macro","title":"SmartIndentationEngine.Template.sigil_TT/2","doc":"Compiles a template string using the `SmartIndentationEngine`.","ref":"SmartIndentationEngine.Template.html#sigil_TT/2"},{"type":"macro","title":"Example - SmartIndentationEngine.Template.sigil_TT/2","doc":"defmodule MyApp.Template do\n      import SmartIndentationEngine.Template\n\n      def render(assigns) do\n        ~TT\"\"\"\n        <%| case @lang do %>\n          <% :fr -> %>\n            <%= include :french %>\n          <% _ -> %>\n            <%= include :english %>\n          <% end %>\n        \"\"\"\n      end\n\n      def french(assigns) do\n        ~TT(Bonjour <%= @name %>)\n      end\n\n      def english(assigns) do\n        ~TT(Hello <%= @name %>)\n      end\n    end\n\n    MyApp.Template.render(lang: :fr, name: \"John\")\n    # => \"Bonjour John\"","ref":"SmartIndentationEngine.Template.html#sigil_TT/2-example"},{"type":"extras","title":"Smart Indentation Engine","doc":"# Smart Indentation Engine\n\n[![CI](https://github.com/goodtouch/smart_indentation_engine/actions/workflows/ci.yml/badge.svg)](https://github.com/goodtouch/smart_indentation_engine/actions/workflows/ci.yml)\n[![License](https://img.shields.io/hexpm/l/smart_indentation_engine.svg)](https://github.com/goodtouch/smart_indentation_engine/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/smart_indentation_engine.svg)](https://hex.pm/packages/smart_indentation_engine)\n[![Hex Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/smart_indentation_engine)\n\nA custom EEx engine that does its best to handle indentation in an intuitive\nway, so that you can enjoy both clean readable templates and well-formatted\noutput.","ref":"readme.html"},{"type":"extras","title":"Features - Smart Indentation Engine","doc":"The engine ships with the following features:\n\n* **Smart Indentation** - Preserves proper indentation in template output.\n* **Template Inclusion** - Supports including (and re-indenting) partial\n  templates.\n* **Assigns Binding** - Access values from the `assigns` binding using the `@`\n  syntax (e.g., `@foo`).\n* **Flexible Spacing** - Works with both spaces and tabs.","ref":"readme.html#features"},{"type":"extras","title":"Overview - Smart Indentation Engine","doc":"This engine extends the default [`EEx.SmartEngine`][hexdocs.eex.smart_engine] by\nimplementing the `<%|` tag to handles indentation in template blocks.\n\nWhen you use it with control flow structures like `if`, `for`, `case`, etc., the\nthe engine automatically aligns the output to match the indentation of the\ncontrol statement.\n\nTemplates included with `<%= include :template %>` are also re-indented to match\nthe surrounding context.","ref":"readme.html#overview"},{"type":"extras","title":"Usage - Smart Indentation Engine","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Smart Indentation Engine","doc":"```elixir\ndef deps do\n  [\n    {:smart_indentation_engine, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Example - Smart Indentation Engine","doc":"Using the `<%|` tag for control flow:\n\n```elixir\nMix.install([\n  {:smart_indentation_engine, \"~> 0.1\"}\n])\n\n\"\"\"\n \n  <%| for name <- [\"world\", \"darkness my old friend\"] do %>\n     hello <%= name %> \n  <% end %>\n \n\"\"\"\n|> EEx.eval_string([], engine: SmartIndentationEngine)\n```\n\nWill produce the following output:\n\n```html\n \n   hello world \n   hello darkness my old friend \n \n\n```","ref":"readme.html#quick-example"},{"type":"extras","title":"The `~TT` Sigil - Smart Indentation Engine","doc":"By importing the `SmartIndentationEngine.Template` module you'll have access to\nthe `~TT` sigil that automatically uses the engine:\n\n```elixir\ndefmodule Template.BasicList do\n  import SmartIndentationEngine.Template\n\n  def render(_assigns \\\\ []) do\n    ~TT\"\"\"\n     \n      <%| for name <- [\"world\", \"darkness my old friend\"] do %>\n         hello <%= name %> \n      <% end %>\n     \n    \"\"\"\n  end\nend\n\nTemplate.BasicList.render()\n```","ref":"readme.html#the-tt-sigil"},{"type":"extras","title":"Using `@` for Assigns - Smart Indentation Engine","doc":"```elixir\ndefmodule Template.AssignedList do\n  import SmartIndentationEngine.Template\n\n  def render(assigns \\\\ []) do\n    ~TT\"\"\"\n     \n      <%| for name <- @names do %>\n         hello <%= name %> \n      <% end %>\n     \n    \"\"\"\n  end\nend\n\nTemplate.AssignedList.render(names: [\"world\", \"darkness my old friend\"])\n```","ref":"readme.html#using-for-assigns"},{"type":"extras","title":"Template Inclusion - Smart Indentation Engine","doc":"You can also include other templates using the `include` function. Included\ntemplates will be reindented to match the surrounding context.\n\n```elixir\ndefmodule Template.IncludedList do\n  import SmartIndentationEngine.Template\n\n  def render(assigns \\\\ []) do\n    ~TT\"\"\"\n     \n       Nice to meet you, hope you guess my name! \n      <%= include :list, names: @names %>\n     \n    \"\"\"\n  end\n\n  def list(assigns) do\n    ~TT\"\"\"\n     \n      <%| for name <- @names do %>\n         hello <%= name %> \n      <% end %>\n     \n    \"\"\"\n  end\nend\n\nTemplate.IncludedList.render(names: [\"world\", \"darkness my old friend\"])\n```\n\nThis produces:\n\n```html\n \n   Nice to meet you, hope you guess my name! \n   \n     hello world \n     hello darkness my old friend \n   \n \n```","ref":"readme.html#template-inclusion"},{"type":"extras","title":"How It Works - Smart Indentation Engine","doc":"When you use the `<%|` marker with control structures, the engine:\n\n1. Captures the indentation context of the control statement\n2. Remove the empty lines introduced by the control statement\n2. Processes the content inside the block (handles nested structures and\n   re-indents included templates)\n3. Dedents the block output to match captured indentation","ref":"readme.html#how-it-works"},{"type":"extras","title":"License - Smart Indentation Engine","doc":"The package is available as open source under the terms of the MIT License.\n\n[hexdocs.eex.smart_engine]: https://hexdocs.pm/eex/EEx.SmartEngine.html","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [v0.1.0] - 2025-04-17\n\n* First release.\n\n[Unreleased]: https://github.com/goodtouch/smart_indentation_engine/compare/v0.1.0...HEAD\n[v0.1.0]: https://github.com/goodtouch/smart_indentation_engine/releases/tag/v0.1.0","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}